# BalderHub Package ``balderhub-ble``

This is a BalderHub package for the [Balder](https://docs.balder.dev) test framework. If you are new to Balder check out the
[official documentation](https://docs.balder.dev) first.

## Installation

You can install the latest release with pip:

```
python -m pip install balderhub-ble
```

# Check out the documentation

If you need more information, 
[checkout the ``balderhub-ble`` documentation](https://hub.balder.dev/projects/ble).


# License

This BalderHub package is free and Open-Source

Copyright (c)  2026  Max Stahlschmidt

Distributed under the terms of the MIT license